@@ -1,38 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012 GRNET S.A. All rights reserved.
+# Copyright (C) 2011-2014 GRNET S.A.
 #
-# Redistribution and use in source and binary forms, with or
-# without modification, are permitted provided that the following
-# conditions are met:
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-#   1. Redistributions of source code must retain the above
-#      copyright notice, this list of conditions and the following
-#      disclaimer.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#   2. Redistributions in binary form must reproduce the above
-#      copyright notice, this list of conditions and the following
-#      disclaimer in the documentation and/or other materials
-#      provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
-# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
-# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
-# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
-# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-# POSSIBILITY OF SUCH DAMAGE.
-#
-# The views and conclusions contained in the software and
-# documentation are those of the authors and should not be
-# interpreted as representing official policies, either expressed
-# or implied, of GRNET S.A.
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """This module is the entrance point for the dialog-based version of the
 snf-image-creator program. The main function will create a dialog where the
@@ -42,11 +24,12 @@ user is asked if he wants to use the program in expert or wizard mode.
 import dialog
 import sys
 import os
-import stat
 import textwrap
 import signal
 import optparse
 import types
+import termios
+import traceback
 
 from image_creator import __version__ as version
 from image_creator.util import FatalError
@@ -57,11 +40,13 @@ from image_creator.output.composite import CompositeOutput
 from image_creator.disk import Disk
 from image_creator.dialog_wizard import start_wizard
 from image_creator.dialog_menu import main_menu
-from image_creator.dialog_util import SMALL_WIDTH, WIDTH, confirm_exit, \
-    Reset, update_background_title
+from image_creator.dialog_util import WIDTH, confirm_exit, Reset, \
+    update_background_title, select_file
+
+PROGNAME = os.path.basename(sys.argv[0])
 
 
-def create_image(d, media, out, tmp):
+def create_image(d, media, out, tmp, snapshot):
     """Create an image out of `media'"""
     d.setBackgroundTitle('snf-image-creator')
 
@@ -76,8 +61,10 @@ def create_image(d, media, out, tmp):
     signal.signal(signal.SIGINT, signal_handler)
     signal.signal(signal.SIGTERM, signal_handler)
     try:
-        snapshot = disk.snapshot()
-        image = disk.get_image(snapshot)
+
+        device = disk.file if not snapshot else disk.snapshot()
+
+        image = disk.get_image(device)
 
         out.output("Collecting image metadata ...")
         metadata = {}
@@ -123,11 +110,11 @@ def create_image(d, media, out, tmp):
         msg = "snf-image-creator detected a %s system on the input media. " \
               "Would you like to run a wizard to assist you through the " \
               "image creation process?\n\nChoose <Wizard> to run the wizard," \
-              " <Expert> to run the snf-image-creator in expert mode or " \
-              "press ESC to quit the program." \
-              % (image.ostype if image.ostype == image.distro or
+              " <Expert> to run snf-image-creator in expert mode or press " \
+              "ESC to quit the program." \
+              % (image.ostype.capitalize() if image.ostype == image.distro or
                  image.distro == "unknown" else "%s (%s)" %
-                 (image.ostype, image.distro))
+                 (image.ostype.capitalize(), image.distro.capitalize()))
 
         update_background_title(session)
 
@@ -151,38 +138,6 @@ def create_image(d, media, out, tmp):
     return 0
 
 
-def select_file(d, media):
-    """Select a media file"""
-    if media == '/':
-        return '/'
-
-    default = os.getcwd() + os.sep
-    while 1:
-        if media is not None:
-            if not os.path.exists(media):
-                d.msgbox("The file `%s' you choose does not exist." % media,
-                         width=SMALL_WIDTH)
-            else:
-                mode = os.stat(media).st_mode
-                if not stat.S_ISDIR(mode):
-                    break
-                default = media
-
-        (code, media) = d.fselect(default, 10, 60, extra_button=1,
-                                  title="Please select an input media.",
-                                  extra_label="Bundle Host")
-        if code in (d.DIALOG_CANCEL, d.DIALOG_ESC):
-            if confirm_exit(d, "You canceled the media selection dialog box."):
-                sys.exit(0)
-            else:
-                media = None
-                continue
-        elif code == d.DIALOG_EXTRA:
-            return '/'
-
-    return media
-
-
 def _dialog_form(self, text, height=20, width=60, form_height=15, fields=[],
                  **kwargs):
     """Display a form box.
@@ -205,7 +160,7 @@ def _dialog_form(self, text, height=20, width=60, form_height=15, fields=[],
         item = field[1]
         item_len = field[2]
         cmd.extend((label, str(line), str(1), item, str(line),
-                   str(label_len + 1), str(input_len), str(item_len)))
+                    str(label_len + 1), str(input_len), str(item_len)))
         line += 1
 
     code, output = self._perform(*(cmd,), **kwargs)
@@ -216,9 +171,9 @@ def _dialog_form(self, text, height=20, width=60, form_height=15, fields=[],
     return (code, output.splitlines())
 
 
-def main():
+def dialog_main(media, logfile, tmpdir, snapshot):
 
-    # In OpenSUSE dialog is buggy under xterm
+    # In openSUSE dialog is buggy under xterm
     if os.environ['TERM'] == 'xterm':
         os.environ['TERM'] = 'linux'
 
@@ -227,14 +182,12 @@ def main():
     # Add extra button in dialog library
     dialog._common_args_syntax["extra_button"] = \
         lambda enable: dialog._simple_option("--extra-button", enable)
-
     dialog._common_args_syntax["extra_label"] = \
         lambda string: ("--extra-label", string)
 
     # Allow yes-no label overwriting
     dialog._common_args_syntax["yes_label"] = \
         lambda string: ("--yes-label", string)
-
     dialog._common_args_syntax["no_label"] = \
         lambda string: ("--no-label", string)
 
@@ -242,61 +195,95 @@ def main():
     if not hasattr(dialog, 'form'):
         d.form = types.MethodType(_dialog_form, d)
 
+    d.setBackgroundTitle('snf-image-creator')
+
+    try:
+        while True:
+            media = select_file(d, init=media, ftype="br", bundle_host=True,
+                                title="Please select an input media.")
+            if media is None:
+                if confirm_exit(
+                        d, "You canceled the media selection dialog box."):
+                    return 0
+                continue
+            break
+
+        log = SimpleOutput(False, logfile) if logfile is not None else Output()
+        while 1:
+            try:
+                out = CompositeOutput([log])
+                out.output("Starting %s v%s ..." % (PROGNAME, version))
+                return create_image(d, media, out, tmpdir, snapshot)
+            except Reset:
+                log.output("Resetting everything ...")
+                continue
+    except FatalError as error:
+        msg = textwrap.fill(str(error), width=WIDTH-4)
+        d.infobox(msg, width=WIDTH, title="Fatal Error")
+        return 1
+
+
+def main():
+    """Entrance Point"""
+    if os.geteuid() != 0:
+        sys.stderr.write("Error: You must run %s as root\n" % PROGNAME)
+        sys.exit(2)
+
     usage = "Usage: %prog [options] [<input_media>]"
     parser = optparse.OptionParser(version=version, usage=usage)
     parser.add_option("-l", "--logfile", type="string", dest="logfile",
                       default=None, help="log all messages to FILE",
                       metavar="FILE")
+    parser.add_option("--no-snapshot", dest="snapshot", default=True,
+                      help="don't snapshot the input media. (THIS IS "
+                      "DANGEROUS AS IT WILL ALTER THE ORIGINAL MEDIA!!!)",
+                      action="store_false")
     parser.add_option("--tmpdir", type="string", dest="tmp", default=None,
                       help="create large temporary image files under DIR",
                       metavar="DIR")
 
-    options, args = parser.parse_args(sys.argv[1:])
+    opts, args = parser.parse_args(sys.argv[1:])
 
     if len(args) > 1:
         parser.error("Wrong number of arguments")
 
-    d.setBackgroundTitle('snf-image-creator')
+    media = args[0] if len(args) == 1 else None
+
+    if opts.tmp is not None and not os.path.isdir(opts.tmp):
+        parser.error("Directory: `%s' specified with --tmpdir is not valid"
+                     % opts.tmp)
 
     try:
-        if os.geteuid() != 0:
-            raise FatalError("You must run %s as root" %
-                             parser.get_prog_name())
-
-        if options.tmp is not None and not os.path.isdir(options.tmp):
-            raise FatalError("The directory `%s' specified with --tmpdir is "
-                             "not valid" % options.tmp)
-
-        logfile = None
-        if options.logfile is not None:
-            try:
-                logfile = open(options.logfile, 'w')
-            except IOError as e:
-                raise FatalError(
-                    "Unable to open logfile `%s' for writing. Reason: %s" %
-                    (options.logfile, e.strerror))
-
-        media = select_file(d, args[0] if len(args) == 1 else None)
+        logfile = open(opts.logfile, 'w') if opts.logfile is not None else None
+    except IOError as error:
+        parser.error("Unable to open logfile `%s' for writing. Reason: %s" %
+                     (opts.logfile, error.strerror))
 
+    try:
+        # Save the terminal attributes
+        attr = termios.tcgetattr(sys.stdin.fileno())
         try:
-            log = SimpleOutput(False, logfile) if logfile is not None \
-                else Output()
-            while 1:
-                try:
-                    out = CompositeOutput([log])
-                    out.output("Starting %s v%s ..." %
-                               (parser.get_prog_name(), version))
-                    ret = create_image(d, media, out, options.tmp)
-                    sys.exit(ret)
-                except Reset:
-                    log.output("Resetting everything ...")
-                    continue
+            ret = dialog_main(media, logfile, opts.tmp, opts.snapshot)
         finally:
-            if logfile is not None:
-                logfile.close()
-    except FatalError as e:
-        msg = textwrap.fill(str(e), width=WIDTH)
-        d.infobox(msg, width=WIDTH, title="Fatal Error")
-        sys.exit(1)
+            # Restore the terminal attributes. If an error occurs make sure
+            # that the terminal turns back to normal.
+            termios.tcsetattr(sys.stdin.fileno(), termios.TCSADRAIN, attr)
+    except:
+        # Clear the screen
+        sys.stdout.write('\033[2J')  # Erase Screen
+        sys.stdout.write('\033[H')  # Cursor Home
+        sys.stdout.flush()
+
+        exception = traceback.format_exc()
+        sys.stderr.write(exception)
+        if logfile is not None:
+            logfile.write(exception)
+
+        sys.exit(3)
+    finally:
+        if logfile is not None:
+            logfile.close()
+
+    sys.exit(ret)
 
 # vim: set sta sts=4 shiftwidth=4 sw=4 et ai :
