@@ -1,37 +1,19 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012 GRNET S.A. All rights reserved.
+# Copyright (C) 2011-2014 GRNET S.A.
 #
-# Redistribution and use in source and binary forms, with or
-# without modification, are permitted provided that the following
-# conditions are met:
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-#   1. Redistributions of source code must retain the above
-#      copyright notice, this list of conditions and the following
-#      disclaimer.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#   2. Redistributions in binary form must reproduce the above
-#      copyright notice, this list of conditions and the following
-#      disclaimer in the documentation and/or other materials
-#      provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY GRNET S.A. ``AS IS'' AND ANY EXPRESS
-# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL GRNET S.A OR
-# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
-# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
-# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-# POSSIBILITY OF SUCH DAMAGE.
-#
-# The views and conclusions contained in the software and
-# documentation are those of the authors and should not be
-# interpreted as representing official policies, either expressed
-# or implied, of GRNET S.A.
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """This module hosts OS-specific code common to all Unix-like OSs."""
 
@@ -42,7 +24,9 @@ class Unix(OSBase):
     """OS class for Unix"""
     sensitive_userdata = [
         '.history',
+        '.sh_history',
         '.bash_history',
+        '.zsh_history',
         '.gnupg',
         '.ssh',
         '.kamakirc',
@@ -79,34 +63,34 @@ class Unix(OSBase):
                 self.image.g.mount_options(mopts, dev, mp)
             except RuntimeError as msg:
                 if mp in critical_mpoints:
-                    self.out.warn('unable to mount %s. Reason: %s' % (mp, msg))
+                    self._mount_error = str(msg)
                     return False
                 else:
-                    self.out.warn('%s (ignored)' % msg)
+                    self._mount_warnings.append('%s (ignored)' % msg)
 
         return True
 
     @sysprep('Removing files under /var/cache')
-    def cleanup_cache(self):
+    def _cleanup_cache(self):
         """Remove all regular files under /var/cache"""
 
         self._foreach_file('/var/cache', self.image.g.rm, ftype='r')
 
     @sysprep('Removing files under /tmp and /var/tmp')
-    def cleanup_tmp(self):
+    def _cleanup_tmp(self):
         """Remove all files under /tmp and /var/tmp"""
 
         self._foreach_file('/tmp', self.image.g.rm_rf, maxdepth=1)
         self._foreach_file('/var/tmp', self.image.g.rm_rf, maxdepth=1)
 
     @sysprep('Emptying all files under /var/log')
-    def cleanup_log(self):
+    def _cleanup_log(self):
         """Empty all files under /var/log"""
 
         self._foreach_file('/var/log', self.image.g.truncate, ftype='r')
 
     @sysprep('Removing files under /var/mail & /var/spool/mail', enabled=False)
-    def cleanup_mail(self):
+    def _cleanup_mail(self):
         """Remove all files under /var/mail and /var/spool/mail"""
 
         self._foreach_file('/var/spool/mail', self.image.g.rm_rf, maxdepth=1)
@@ -114,8 +98,8 @@ class Unix(OSBase):
         self._foreach_file('/var/mail', self.image.g.rm_rf, maxdepth=1)
 
     @sysprep('Removing sensitive user data')
-    def cleanup_userdata(self):
-        """Delete sensitive userdata"""
+    def _cleanup_userdata(self):
+        """Delete sensitive user data"""
 
         homedirs = ['/root']
         if self.image.g.is_dir('/home/'):
