@@ -1,8 +1,8 @@
 
-__version__ = "0.7"
+__version__ = "0.7.1"
 __version_vcs_info__ = {
-    'branch': 'master',
-    'revid': 'ab4d13b',
-    'revno': 571}
+    'branch': 'hotfix-0.7.1',
+    'revid': '080bf9c',
+    'revno': 578}
 __version_user_email__ = "skalkoto@grnet.gr"
 __version_user_name__ = "Nikos Skalkotos"
